==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-mainmenu/mainmenu_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="95"/>
        <source>Search...</source>
        <translation>Søg...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="101"/>
        <source>Show/hide main menu</source>
        <translation>Vis/skjul hovedmenu</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>Indstillinger for hovedmenu</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Knaptekst:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Brugerdefineret skriftstørrelse:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>Menufil</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>Menu-fil:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="175"/>
        <source>max. item width:</source>
        <translation>maks. bredde for objekt:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="182"/>
        <source>Show matching entries:</source>
        <translation>Vis tilhørende punkter:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="196"/>
        <source>Maximum visible items:</source>
        <translation>Maksimum synlige objekter:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="203"/>
        <source>Filter menu entries</source>
        <translation>Filtrér menupunkter</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="210"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="223"/>
        <source>Hide menu entries while searching</source>
        <translation>Skjul menupunkter under søgning</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>Tastaturgenvej</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Klik på knappen for at optage genvej:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="71"/>
        <source>Reset</source>
        <translation>Nulstil</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="156"/>
        <source>Choose icon file</source>
        <translation>Vælg ikon-fil</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="158"/>
        <source>Images (*.svg *.png)</source>
        <translation>Billeder (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="170"/>
        <source>Choose menu file</source>
        <translation>Vælg menufil</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="172"/>
        <source>Menu files (*.menu)</source>
        <translation>Menufiler (*.menu)</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-mainmenu/mainmenu_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="96"/>
        <source>Search...</source>
        <translation>Søg...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="102"/>
        <source>Show/hide main menu</source>
        <translation>Vis/skjul hovedmenu</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>Indstillinger for hovedmenu</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Knaptekst:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Brugerdefineret skriftstørrelse:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>Menufil</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>Menu-fil:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>max. item width:</source>
        <translation>maks. bredde for objekt:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>Vis tilhørende punkter:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>Maksimum synlige objekter:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>Filtrér menupunkter</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>Skjul menupunkter under søgning</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>Ryd søgning når menuen vises</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>Tastaturgenvej</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Klik på knappen for at optage genvej:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="71"/>
        <source>Reset</source>
        <translation>Nulstil</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="165"/>
        <source>Choose icon file</source>
        <translation>Vælg ikon-fil</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="167"/>
        <source>Images (*.svg *.png)</source>
        <translation>Billeder (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="179"/>
        <source>Choose menu file</source>
        <translation>Vælg menufil</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="181"/>
        <source>Menu files (*.menu)</source>
        <translation>Menufiler (*.menu)</translation>
    </message>
</context>
</TS>
